@@ -5,8 +5,8 @@ use core::ffi::c_void;
 use libc::size_t;
 
 extern "C" {
-    /// Allocate the memory with the given alignment and size. 
-    /// On success, it returns a pointer pointing to the required memory address. 
+    /// Allocate the memory with the given alignment and size.
+    /// On success, it returns a pointer pointing to the required memory address.
     /// On failure, it returns a null pointer.
     /// The client must assure the following things:
     /// - `alignment` is greater than zero
@@ -14,15 +14,15 @@ extern "C" {
     /// The program may be forced to abort if the constrains are not full-filled.
     pub fn rust_alloc(alignment: size_t, size: size_t) -> *mut c_void;
 
-    /// De-allocate the memory at the given address with the given alignment and size. 
+    /// De-allocate the memory at the given address with the given alignment and size.
     /// The client must assure the following things:
     /// - the memory is acquired using the same allocator and the pointer points to the start position.
     /// - `alignment` and `size` is the same as allocation
     /// The program may be forced to abort if the constrains are not full-filled.
     pub fn rust_dealloc(ptr: *mut c_void, alignment: size_t, size: size_t) -> c_void;
 
-    /// Re-allocate the memory at the given address with the given alignment and size. 
-    /// On success, it returns a pointer pointing to the required memory address. 
+    /// Re-allocate the memory at the given address with the given alignment and size.
+    /// On success, it returns a pointer pointing to the required memory address.
     /// The memory content within the `new_size` will remains the same as previous.
     /// On failure, it returns a null pointer. In this situation, the previous memory is not returned to the allocator.
     /// The client must assure the following things:
@@ -30,13 +30,18 @@ extern "C" {
     /// - `alignment` and `old_size` is the same as allocation
     /// - `alignment` fulfills all the requirements as `rust_alloc`
     /// The program may be forced to abort if the constrains are not full-filled.
-    pub fn rust_realloc(ptr: *mut c_void, alignment: size_t, old_size: size_t, new_size: size_t) -> *mut c_void;
-    
+    pub fn rust_realloc(
+        ptr: *mut c_void,
+        alignment: size_t,
+        old_size: size_t,
+        new_size: size_t,
+    ) -> *mut c_void;
+
     /// Allocate `count` items of `size` length each.
     /// Returns `null` if `count * size` overflows or on out-of-memory.
     /// All items are initialized to zero.
     pub fn sn_calloc(count: usize, size: usize) -> *mut c_void;
-    
+
     /// Allocate `size` bytes.
     /// Returns pointer to the allocated memory or null if out of memory.
     /// Returns a unique pointer if called with `size` 0.
@@ -55,7 +60,7 @@ extern "C" {
     /// Free previously allocated memory.
     /// The pointer `p` must have been allocated before (or be null).
     pub fn sn_free(p: *mut c_void);
-	
+
     /// Return the available bytes in a memory block.
     pub fn sn_malloc_usable_size(p: *const c_void) -> usize;
 }
@@ -67,7 +72,10 @@ mod tests {
     #[test]
     fn it_frees_memory_malloc() {
         let ptr = unsafe { rust_alloc(8, 8) } as *mut u8;
-        unsafe {*ptr = 127; assert_eq!(*ptr, 127)};
+        unsafe {
+            *ptr = 127;
+            assert_eq!(*ptr, 127)
+        };
         unsafe { rust_dealloc(ptr as *mut c_void, 8, 8) };
     }
     #[test]
@@ -75,20 +83,23 @@ mod tests {
         let ptr = unsafe { sn_malloc(8) } as *mut u8;
         unsafe { sn_free(ptr as *mut c_void) };
     }
-	
+
     #[test]
     fn it_frees_memory_sn_realloc() {
         let ptr = unsafe { sn_malloc(8) } as *mut u8;
         let ptr = unsafe { sn_realloc(ptr as *mut c_void, 8) } as *mut u8;
         unsafe { sn_free(ptr as *mut c_void) };
     }
-    
+
     #[test]
     fn it_reallocs_correctly() {
         let mut ptr = unsafe { rust_alloc(8, 8) } as *mut u8;
-        unsafe {*ptr = 127; assert_eq!(*ptr, 127)};
+        unsafe {
+            *ptr = 127;
+            assert_eq!(*ptr, 127)
+        };
         ptr = unsafe { rust_realloc(ptr as *mut c_void, 8, 8, 16) } as *mut u8;
-        unsafe {assert_eq!(*ptr, 127)};
+        unsafe { assert_eq!(*ptr, 127) };
         unsafe { rust_dealloc(ptr as *mut c_void, 8, 16) };
     }
 
